/*
 *	Title:		o3find
 *	Version:	0.8.1
 *	Created by:	Paolo Copello
 *	Home page:	http://web.tiscali.it/fanelia
 *	
 *	Copyright (C) 2003-2005 Paolo Copello
 *	
 *	******************************************
 *	This file is part of o3find
 *	******************************************
 *	
 *	o3find is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	any later version.
 *	
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *	
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *	
 */





#include <string>
#include <list>
#include <map>
//#include <vector>

using namespace std;


namespace Fanel
{


class OoXmlMemFile;

class OoFinder
{
public:
	enum SEARCH_IN { CONTENT_ONLY, META_ONLY, CONTENT_AND_META };
	
	OoFinder(bool bCaseSensitive, bool bShowErrors, bool bShowNotFound, bool bBriefMode,
			SEARCH_IN search_in, bool bReadAlreadyOpenFile, bool bIgnoreStyle);
	virtual ~OoFinder();

	void Find(const list<string> & fileList, const string& sToFind);
	void Find(const string& sFile, const string& sToFind);

	void Stop();

//	void GetResults(int& iScanned, int& iFound, int& iErrors, list<string>& results);

//	const list<string>& GetResultList() const;



protected:
	void InternalFind(const string& sFile);
	void NormalFindInFile(const string& sFile);
	void FindInXML(const string& sFile, OoXmlMemFile& memFile);
	bool FindSubstring(const char* str, int nLength, const string& sToBeFound);
	bool FindSubstringW(const char* str, int nLength, const wstring& sToBeFound);
	void Clear();
	virtual void ReportFound(const string& sFile, const string& sLine) = 0;
	virtual void ReportError(const string& sFile, const string& sMessage) = 0;
	virtual void ReportNotFound(const string& sFile) = 0;

	virtual void AdaptStringToXml(const string& strIn, string& strOut);
	virtual void UnAdaptStringFromXml(const string& strIn, string& strOut);
	virtual void AdaptStringToUnicodeSearch(const string& strIn, wstring& strOut);

//	int _iScanned;
//	int _iFound;
//	int _iErrors;
//	list<string> _results;
	
	bool _bBriefMode;
	bool _bCaseSensitive;
	bool _bShowErrors;
	bool _bShowNotFound;
	bool _bReadAlreadyOpenFile;
	bool _bIgnoreStyle;

	string _sToFindInXml;
	string _sToFindUnadapted;
	wstring _sToFindNormalSearchUnicode;

	SEARCH_IN	_search_in;

#ifdef FANEL_MULTITHREAD_SUPPORT
	volatile
#endif
	bool _bRunning;

	// adapt maps
	typedef map<char, string> AdaptMapType ;

	AdaptMapType _adaptMap;

#ifdef WIN32
	bool _bAccentedLettersSupported;
#endif

};













}
// end namespace Fanel


